==> auth-2.3.0816.5-sources.jar: com/zing/zalo/zalosdk/oauth/WebLoginActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTransaction;
import android.text.TextUtils;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.auth.internal.i;
import com.zing.zalo.zalosdk.auth.internal.j;
import com.zing.zalo.zalosdk.auth.internal.j.b;
import com.zing.zalo.zalosdk.auth.internal.l;
import com.zing.zalo.zalosdk.auth.internal.l.d;
import com.zing.zalo.zalosdk.auth.internal.m;
import com.zing.zalo.zalosdk.auth.internal.n;
import com.zing.zalo.zalosdk.auth.internal.o;
import com.zing.zalo.zalosdk.auth.internal.p;
import com.zing.zalo.zalosdk.common.UtilsCore;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.payment.direct.PaymentProcessingDialog;
import com.zing.zalo.zalosdk.payment.direct.PaymentProcessingDialog.OnCloseListener;
import org.json.JSONException;
import org.json.JSONObject;

@SuppressLint({"NewApi"})
public class WebLoginActivity extends FragmentActivity implements OnClickListener, com.zing.zalo.zalosdk.auth.internal.i.a, b, d, com.zing.zalo.zalosdk.auth.internal.m.a, com.zing.zalo.zalosdk.auth.internal.n.a, p.b {
    l a;
    m b;
    p c;
    j d;
    n e;
    FrameLayout f;
    int g;
    PaymentProcessingDialog h;
    TextView i;
    ImageView j;
    boolean k;

    public interface a {
        void a();
    }

    public static Intent a(Context context, boolean z) {
        Intent intent = new Intent(context, WebLoginActivity.class);
        intent.putExtra("registerOnly", z);
        return intent;
    }

    private void a(Fragment fragment) {
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.g, fragment, fragment.getClass().getSimpleName());
        beginTransaction.setTransition(4097);
        beginTransaction.addToBackStack(fragment.getClass().getSimpleName());
        beginTransaction.commit();
    }

    private void e(String str) {
        this.a = l.b(str);
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.g, this.a, "login-fragment");
        beginTransaction.commitAllowingStateLoss();
    }

    private void h() {
        FragmentManager supportFragmentManager = getSupportFragmentManager();
        for (int backStackEntryCount = supportFragmentManager.getBackStackEntryCount(); backStackEntryCount > 0; backStackEntryCount--) {
            supportFragmentManager.popBackStackImmediate();
        }
    }

    public final void a() {
        this.b = m.a(false, null);
        a(this.b);
    }

    public final void a(int i, long j, String str, int i2, String str2, boolean z) {
        Intent intent = new Intent();
        intent.putExtra("error", i);
        intent.putExtra("uid", j);
        intent.putExtra("code", str);
        intent.putExtra("isRegister", z);
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            jSONObject2.put("display_name", str2);
            jSONObject2.put("zprotect", i2);
            jSONObject.put("data", jSONObject2);
        } catch (JSONException e) {
        }
        intent.putExtra("data", jSONObject.toString());
        setResult(-1, intent);
        finish();
    }

    public final void a(Activity activity, final a aVar, String str, String str2, String str3, String str4, String str5) {
        final Dialog dialog = new Dialog(activity);
        dialog.requestWindowFeature(1);
        dialog.setContentView(R.layout.zalo_web_regis_dialog_confirm);
        dialog.getWindow().setBackgroundDrawable(new ColorDrawable(0));
        if (!TextUtils.isEmpty(str3)) {
            ((TextView) dialog.findViewById(R.id.content)).setText(str3);
        }
        if (TextUtils.isEmpty(str)) {
            dialog.findViewById(UtilsCore.getResourceId(activity, "line", "id")).setVisibility(8);
            dialog.findViewById(UtilsCore.getResourceId(activity, "txt_title", "id")).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(UtilsCore.getResourceId(activity, "txt_title", "id"))).setText(str);
        }
        if (TextUtils.isEmpty(str2)) {
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setVisibility(0);
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setText(str2);
        }
        if (TextUtils.isEmpty(str5)) {
            dialog.findViewById(R.id.btn_add).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.btn_add)).setText(str5);
            dialog.findViewById(R.id.btn_add).setVisibility(0);
            dialog.findViewById(R.id.btn_add).setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                    if (aVar != null) {
                        aVar.a();
                    }
                }
            });
        }
        if (TextUtils.isEmpty(str4)) {
            dialog.findViewById(R.id.btn_cancel).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.btn_cancel)).setText(str4);
            dialog.findViewById(R.id.btn_cancel).setVisibility(0);
            dialog.findViewById(R.id.btn_cancel).setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                }
            });
        }
        if ((!TextUtils.isEmpty(str4) && TextUtils.isEmpty(str5)) || (TextUtils.isEmpty(str4) && !TextUtils.isEmpty(str5))) {
            if (TextUtils.isEmpty(str4)) {
                Object obj = str5;
            }
            dialog.findViewById(R.id.btn_cancel).setVisibility(8);
            dialog.findViewById(R.id.btn_add).setVisibility(8);
            TextView textView = (TextView) dialog.findViewById(UtilsCore.getResourceId(activity, "centerbtn", "id"));
            textView.setVisibility(0);
            textView.setText(r11);
            textView.setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                    if (aVar != null) {
                        aVar.a();
                    }
                }
            });
        }
        dialog.show();
    }

    public final void a(String str) {
        this.b = m.a(true, str);
        a(this.b);
    }

    public final void a(String str, String str2) {
        a(this, null, str, null, str2, null, getString(Utils.getResourceId(this, "txt_close", "string")));
    }

    public final void a(String str, String str2, long j, String str3, String str4, String str5, String str6, int i, String str7) {
        h();
        this.c = p.a(str, str2, j, str3, str4, str5, str6, i, str7);
        a(this.c);
    }

    public final void a(String str, String str2, long j, String str3, boolean z) {
        h();
        this.d = j.a(str, str2, j, str3, z);
        a(this.d);
    }

    public final void a(String str, String str2, String str3, boolean z, String str4) {
        a(i.a(str, str2, str3, z, str4));
    }

    public final void b() {
        if (this.h == null) {
            this.h = new PaymentProcessingDialog(this, new OnCloseListener(this) {
                final /* synthetic */ WebLoginActivity a;

                {
                    this.a = r1;
                }

                public final void onClose() {
                }
            });
        }
        if (!this.h.isShowing()) {
            this.h.show();
        }
    }

    public final void b(String str) {
        if (this.a == null) {
            h();
            e(str);
            return;
        }
        this.a.c(str);
        h();
    }

    public final void c() {
        if (this.h != null && this.h.isShowing()) {
            this.h.dismiss();
            this.h = null;
        }
    }

    public final void c(String str) {
        if (this.i != null) {
            this.i.setText(str);
        }
    }

    public final void d() {
        if (this.j != null) {
            this.j.setVisibility(0);
        }
    }

    public final void d(String str) {
        if (this.b != null) {
            this.b.getArguments().putString("regioncode", str);
            this.b.b(str);
        }
    }

    public final void e() {
        if (this.j != null) {
            this.j.setVisibility(4);
        }
    }

    public final void f() {
        a(o.e());
    }

    public final void g() {
        if (this.e == null) {
            this.e = n.e();
        }
        a(this.e);
    }

    protected void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        ZaloSDK.Instance.onActivityResult(this, i, i2, intent);
    }

    public void onBackPressed() {
        if (this.j != null && this.j.getVisibility() == 0) {
            super.onBackPressed();
        }
    }

    public void onClick(View view) {
        if (view == this.j) {
            UtilsCore.hideSoftKeyboard(this);
            onBackPressed();
        }
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        this.k = getIntent().getBooleanExtra("registerOnly", false);
        setContentView(UtilsCore.getResourceId(this, "zalosdk_activity_zalo_web_login", "layout"));
        this.g = UtilsCore.getResourceId(this, "zalosdk_weblogin_container", "id");
        this.f = (FrameLayout) findViewById(this.g);
        this.i = (TextView) findViewById(UtilsCore.getResourceId(this, "zalosdk_txt_title", "id"));
        this.j = (ImageView) findViewById(UtilsCore.getResourceId(this, "zalosdk_back_control", "id"));
        this.j.setOnClickListener(this);
        if (bundle != null) {
            return;
        }
        if (this.k) {
            this.b = m.a(false, null);
            FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
            beginTransaction.replace(this.g, this.b, "register-fragment");
            beginTransaction.commit();
            return;
        }
        e(null);
    }

    public void onDestroy() {
        super.onDestroy();
        Utils.clearTextLineCache();
    }
}

==> auth-2.3.0911.7-sources.jar: com/zing/zalo/zalosdk/oauth/WebLoginActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTransaction;
import android.text.TextUtils;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.auth.internal.k;
import com.zing.zalo.zalosdk.auth.internal.l;
import com.zing.zalo.zalosdk.auth.internal.l.b;
import com.zing.zalo.zalosdk.auth.internal.n;
import com.zing.zalo.zalosdk.auth.internal.n.d;
import com.zing.zalo.zalosdk.auth.internal.o;
import com.zing.zalo.zalosdk.auth.internal.p;
import com.zing.zalo.zalosdk.auth.internal.q;
import com.zing.zalo.zalosdk.auth.internal.r;
import com.zing.zalo.zalosdk.common.UtilsCore;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.payment.direct.PaymentProcessingDialog;
import com.zing.zalo.zalosdk.payment.direct.PaymentProcessingDialog.OnCloseListener;
import org.json.JSONException;
import org.json.JSONObject;

@SuppressLint({"NewApi"})
public class WebLoginActivity extends FragmentActivity implements OnClickListener, com.zing.zalo.zalosdk.auth.internal.k.a, b, d, com.zing.zalo.zalosdk.auth.internal.o.a, com.zing.zalo.zalosdk.auth.internal.p.a, r.b {
    n a;
    o b;
    r c;
    l d;
    p e;
    FrameLayout f;
    int g;
    PaymentProcessingDialog h;
    TextView i;
    ImageView j;
    boolean k;

    public interface a {
        void a();
    }

    public static Intent a(Context context, boolean z) {
        Intent intent = new Intent(context, WebLoginActivity.class);
        intent.putExtra("registerOnly", z);
        return intent;
    }

    private void a(Fragment fragment) {
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.g, fragment, fragment.getClass().getSimpleName());
        beginTransaction.setTransition(4097);
        beginTransaction.addToBackStack(fragment.getClass().getSimpleName());
        beginTransaction.commit();
    }

    private void e(String str) {
        this.a = n.b(str);
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.g, this.a, "login-fragment");
        beginTransaction.commitAllowingStateLoss();
    }

    private void h() {
        FragmentManager supportFragmentManager = getSupportFragmentManager();
        for (int backStackEntryCount = supportFragmentManager.getBackStackEntryCount(); backStackEntryCount > 0; backStackEntryCount--) {
            supportFragmentManager.popBackStackImmediate();
        }
    }

    public final void a() {
        this.b = o.a(false, null);
        a(this.b);
    }

    public final void a(int i, long j, String str, int i2, String str2, boolean z) {
        Intent intent = new Intent();
        intent.putExtra("error", i);
        intent.putExtra("uid", j);
        intent.putExtra("code", str);
        intent.putExtra("isRegister", z);
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            jSONObject2.put("display_name", str2);
            jSONObject2.put("zprotect", i2);
            jSONObject.put("data", jSONObject2);
        } catch (JSONException e) {
        }
        intent.putExtra("data", jSONObject.toString());
        setResult(-1, intent);
        finish();
    }

    public final void a(Activity activity, final a aVar, String str, String str2, String str3, String str4, String str5) {
        final Dialog dialog = new Dialog(activity);
        dialog.requestWindowFeature(1);
        dialog.setContentView(R.layout.zalo_web_regis_dialog_confirm);
        dialog.getWindow().setBackgroundDrawable(new ColorDrawable(0));
        if (!TextUtils.isEmpty(str3)) {
            ((TextView) dialog.findViewById(R.id.content)).setText(str3);
        }
        if (TextUtils.isEmpty(str)) {
            dialog.findViewById(UtilsCore.getResourceId(activity, "line", "id")).setVisibility(8);
            dialog.findViewById(UtilsCore.getResourceId(activity, "txt_title", "id")).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(UtilsCore.getResourceId(activity, "txt_title", "id"))).setText(str);
        }
        if (TextUtils.isEmpty(str2)) {
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setVisibility(0);
            ((TextView) dialog.findViewById(R.id.phoneNumber)).setText(str2);
        }
        if (TextUtils.isEmpty(str5)) {
            dialog.findViewById(R.id.btn_add).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.btn_add)).setText(str5);
            dialog.findViewById(R.id.btn_add).setVisibility(0);
            dialog.findViewById(R.id.btn_add).setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                    if (aVar != null) {
                        aVar.a();
                    }
                }
            });
        }
        if (TextUtils.isEmpty(str4)) {
            dialog.findViewById(R.id.btn_cancel).setVisibility(8);
        } else {
            ((TextView) dialog.findViewById(R.id.btn_cancel)).setText(str4);
            dialog.findViewById(R.id.btn_cancel).setVisibility(0);
            dialog.findViewById(R.id.btn_cancel).setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                }
            });
        }
        if ((!TextUtils.isEmpty(str4) && TextUtils.isEmpty(str5)) || (TextUtils.isEmpty(str4) && !TextUtils.isEmpty(str5))) {
            if (TextUtils.isEmpty(str4)) {
                Object obj = str5;
            }
            dialog.findViewById(R.id.btn_cancel).setVisibility(8);
            dialog.findViewById(R.id.btn_add).setVisibility(8);
            TextView textView = (TextView) dialog.findViewById(UtilsCore.getResourceId(activity, "centerbtn", "id"));
            textView.setVisibility(0);
            textView.setText(r11);
            textView.setOnClickListener(new OnClickListener(this) {
                final /* synthetic */ WebLoginActivity c;

                public final void onClick(View view) {
                    dialog.dismiss();
                    if (aVar != null) {
                        aVar.a();
                    }
                }
            });
        }
        dialog.show();
    }

    public final void a(String str) {
        this.b = o.a(true, str);
        a(this.b);
    }

    public final void a(String str, String str2) {
        a(this, null, str, null, str2, null, getString(Utils.getResourceId(this, "txt_close", "string")));
    }

    public final void a(String str, String str2, long j, String str3, String str4, String str5, String str6, int i, String str7) {
        h();
        this.c = r.a(str, str2, j, str3, str4, str5, str6, i, str7);
        a(this.c);
    }

    public final void a(String str, String str2, long j, String str3, boolean z) {
        h();
        this.d = l.a(str, str2, j, str3, z);
        a(this.d);
    }

    public final void a(String str, String str2, String str3, boolean z, String str4) {
        a(k.a(str, str2, str3, z, str4));
    }

    public final void b() {
        if (this.h == null) {
            this.h = new PaymentProcessingDialog(this, new OnCloseListener(this) {
                final /* synthetic */ WebLoginActivity a;

                {
                    this.a = r1;
                }

                public final void onClose() {
                }
            });
        }
        if (!this.h.isShowing()) {
            this.h.show();
        }
    }

    public final void b(String str) {
        if (this.a == null) {
            h();
            e(str);
            return;
        }
        this.a.c(str);
        h();
    }

    public final void c() {
        if (this.h != null && this.h.isShowing()) {
            this.h.dismiss();
            this.h = null;
        }
    }

    public final void c(String str) {
        if (this.i != null) {
            this.i.setText(str);
        }
    }

    public final void d() {
        if (this.j != null) {
            this.j.setVisibility(0);
        }
    }

    public final void d(String str) {
        if (this.b != null) {
            this.b.getArguments().putString("regioncode", str);
            this.b.b(str);
        }
    }

    public final void e() {
        if (this.j != null) {
            this.j.setVisibility(4);
        }
    }

    public final void f() {
        a(q.e());
    }

    public final void g() {
        if (this.e == null) {
            this.e = p.e();
        }
        a(this.e);
    }

    protected void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        ZaloSDK.Instance.onActivityResult(this, i, i2, intent);
    }

    public void onBackPressed() {
        if (this.j != null && this.j.getVisibility() == 0) {
            super.onBackPressed();
        }
    }

    public void onClick(View view) {
        if (view == this.j) {
            UtilsCore.hideSoftKeyboard(this);
            onBackPressed();
        }
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        this.k = getIntent().getBooleanExtra("registerOnly", false);
        setContentView(UtilsCore.getResourceId(this, "zalosdk_activity_zalo_web_login", "layout"));
        this.g = UtilsCore.getResourceId(this, "zalosdk_weblogin_container", "id");
        this.f = (FrameLayout) findViewById(this.g);
        this.i = (TextView) findViewById(UtilsCore.getResourceId(this, "zalosdk_txt_title", "id"));
        this.j = (ImageView) findViewById(UtilsCore.getResourceId(this, "zalosdk_back_control", "id"));
        this.j.setOnClickListener(this);
        if (bundle != null) {
            return;
        }
        if (this.k) {
            this.b = o.a(false, null);
            FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
            beginTransaction.replace(this.g, this.b, "register-fragment");
            beginTransaction.commit();
            return;
        }
        e(null);
    }

    public void onDestroy() {
        super.onDestroy();
        Utils.clearTextLineCache();
    }
}
